@@ -291,7 +291,7 @@ def beta_linear_log_snr(t):
 
 @torch.jit.script
 def alpha_cosine_log_snr(t, s: float = 0.008):
-    return -log((torch.cos((t + s) / (1 + s) * torch.pi * 0.5) ** -2) - 1)
+    return -log((torch.cos((t + s) / (1 + s) * math.pi * 0.5) ** -2) - 1)
 
 def log_snr_to_alpha_sigma(log_snr):
     return torch.sqrt(torch.sigmoid(log_snr)), torch.sqrt(torch.sigmoid(-log_snr))
